yakumo.neutron.v2.lbaas.load_balancer

Package yakumo :: Package neutron :: Package v2 :: Package lbaas :: Module load_balancer |
[hide private]
[frames] | no frames]

# Module load_balancer

source code

Resource class and its manager for LBaaS load balancers in Networking V2 API

Classes | [hide private]
| Resource Resource class for LBaaS load balancers in Networking V2 API
| Manager Manager class for LBaaS load balancers in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lbaas``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('listeners', 'listeners', mapper.Li
      st(mapper.Resource('neutron.lbaas.listener'))), ('vip_address', 'vip_a
      ddress', mapper.Noop), ('subnet', 'vip_subnet_id', mapper.Resource('ne
      utron.subnet')), ('operating_status', 'operating_status', mapper.Noop)
      , ('provisioning_status', 'provisioning_status', mapper.Noop), ('proje
      ct', 'tenant_id', mapper.Resource('project')), ('is_enabled', 'admin_s
      tate_up', mapper.Noop),]